@@ -7,7 +7,7 @@ no if $] >= 5.018, warnings => 'experimental::smartmatch';
 use parent qw/WWW::Search/;
 use re '/s';
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002';
 our $MAINTAINER = 'Marius Gavrilescu <marius@ieval.ro>';
 
 use WWW::Search::Torrentz::Result;
@@ -79,7 +79,7 @@ __END__
 
 =head1 NAME
 
-WWW::Search::Torrentz - search torrentz.eu with WWW::Search
+WWW::Search::Torrentz - [DEPRECATED] search torrentz.eu with WWW::Search
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,11 @@ WWW::Search::Torrentz - search torrentz.eu with WWW::Search
 
 =head1 DESCRIPTION
 
-WWW::Search::Torrentz is a subclass of WWW::Search that searches the L<https://torrentz.eu> search aggregator.
+This module is deprecated since L<https://torrentz.eu> was shut down
+in August 2016.
+
+WWW::Search::Torrentz is a subclass of WWW::Search that searches the
+L<https://torrentz.eu> search aggregator.
 
 To use this module, read the L<WWW::Search> documentation.
 
