@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use parent qw/WWW::SearchResult/;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002';
 
 use HTML::TreeBuilder;
 use URI::Escape qw/uri_escape/;
@@ -113,7 +113,7 @@ __END__
 
 =head1 NAME
 
-WWW::Search::Torrentz::Result - a result of a WWW::Search::Torrentz search
+WWW::Search::Torrentz::Result - [DEPRECATED] a result of a WWW::Search::Torrentz search
 
 =head1 SYNOPSIS
 
